@@ -15,6 +15,7 @@ from typing import Callable, List, Optional, Tuple
 
 from .command import ARGS, DEAMON, EXPIRES, FUNC, TIMEOUT, Command
 from .const import __dev_mode__
+from .exceptions import CorruptStateError
 from .message import Message
 
 DONT_CREATE_MESSAGES = 3  # duplicate
@@ -189,6 +190,8 @@ class MessageTransport(asyncio.Transport):
         for p in self._protocols:
             try:
                 p.data_received(msg)
+            except CorruptStateError as exc:
+                _LOGGER.error("Exception in callback to application layer: %s", exc)
             except:  # noqa: E722  # TODO: remove broad-except
                 _LOGGER.exception("Exception in callback to application layer")
 
