@@ -7,6 +7,8 @@ import logging
 from datetime import timedelta as td
 
 from .const import I_, RP, RQ, W_, __dev_mode__  # noqa: F401, isort: skip
+
+
 from .const import (  # noqa: F401, isort: skip
     _0001,
     _0002,
@@ -43,7 +45,6 @@ from .const import (  # noqa: F401, isort: skip
     _1F09,
     _1F41,
     _1FC9,
-    _1FCA,
     _1FD4,
     _2249,
     _22C9,
@@ -90,8 +91,9 @@ EXPIRY = "expiry"
 RAMSES_CODES = {  # rf_unknown
     _0001: {
         NAME: "rf_unknown",
-        W_: r"^(0[0-9A-F]|F[ACF])000005(05|01)$",
-    },  # TODO: there appears to be a RQ/RP for UFC
+        I_: r"^00FFFF02(00|FF)$",  # loopback
+        W_: r"^(0[0-9A-F]|F[CF])000005(01|05)$",
+    },  # TODO: there appears to be a dodgy? RQ/RP for UFC
     _0002: {  # WIP: outdoor_sensor
         NAME: "outdoor_sensor",
         I_: r"^0[0-4][0-9A-F]{4}(00|01|02|05)$",  # Domoticz sends ^02!!
@@ -219,6 +221,7 @@ RAMSES_CODES = {  # rf_unknown
         # NOTE: RFG100 uses a domain id! (00|01)
         # 19:14:24.662 051 RQ --- 30:185469 01:037519 --:------ 10A0 001 00
         # 19:14:31.463 053 RQ --- 30:185469 01:037519 --:------ 10A0 001 01
+        I_: r"^0[01]([0-9A-F]{10})?$",  # NOTE: RQ/07/10A0 has a payload
         RQ: r"^0[01]([0-9A-F]{10})?$",  # NOTE: RQ/07/10A0 has a payload
         EXPIRES: td(hours=4),
     },
@@ -235,8 +238,8 @@ RAMSES_CODES = {  # rf_unknown
         # RP --- 13:163733 01:145038 --:------ 1100 008 00180400FF7FFF01
         # RQ --- 01:145038 13:035462 --:------ 1100 008 FC240428007FFF01  # not bolier relay
         # RP --- 13:035462 01:145038 --:------ 1100 008 00240428007FFF01
+        I_: r"^(00|FC)[0-9A-F]{6}(00|FF)([0-9A-F]{4}01)+$",
         RQ: r"^(00|FC)([0-9A-F]{6}(00|FF)([0-9A-F]{4}01)+)?$",  # RQ/13:/00, or RQ/01:/FC:
-        RP: r"^(00|FC)[0-9A-F]{6}(00|FF)([0-9A-F]{4}01)+$",
         W_: r"^(00|FC)[0-9A-F]{6}(00|FF)([0-9A-F]{4}01)+$",  # TODO: is there no I?
         EXPIRES: td(days=1),
     },
@@ -306,12 +309,6 @@ RAMSES_CODES = {  # rf_unknown
         I_: r"^((0[0-9A-F]|F[9ABCF])([0-9A-F]{10}))+$",
         W_: r"^((0[0-9A-F]|F[9ABCF])([0-9A-F]{10}))+$",
     },
-    _1FCA: {  # unknown
-        #  W --- 30:248208 34:021943 --:------ 1FCA 009 00-01FF-7BC990-FFFFFF  # sent x2
-        # RP --- 30:248208 18:006402 --:------ 1FCA 009 00-xxxx-302E31-322E30  # 2 STAs
-        NAME: "message_1fca",
-        W_: r"^00[0-9A-F]{4}[0-9A-F]{12}$",
-    },
     _1FD4: {  # opentherm_sync
         NAME: "opentherm_sync",
         I_: r"^00([0-9A-F]{4})$",
@@ -347,15 +344,19 @@ RAMSES_CODES = {  # rf_unknown
     _2309: {  # setpoint
         NAME: "setpoint",
         I_: r"^(0[0-9A-F]{5})+$",
+        W_: r"^0[0-9A-F]{5}$",
         # RQ --- 12:010740 01:145038 --:------ 2309 003 03073A # No RPs
         RQ: r"^0[0-9A-F]([0-9A-F]{4})?$",  # NOTE: 12 uses: r"^0[0-9A-F]$"
         EXPIRES: td(minutes=30),
     },
     _2349: {  # zone_mode
         NAME: "zone_mode",
-        I_: r"^0[0-9A-F]([0-9A-F]{12}){1,2}$",
-        # RQ --- 22:070483 01:063844 --:------ 2349 007 06070803000027
+        I_: r"^0[0-9A-F]{5}0[0-4][0-9A-F]{6}([0-9A-F]{12})?$",
+        W_: r"^0[0-9A-F]{5}0[0-4][0-9A-F]{6}([0-9A-F]{12})?$",
+        # .W --- 18:141846 01:050858 --:------ 2349 013 02-0960-04-FFFFFF-0409160607E5
+        # .W --- 18:141846 01:050858 --:------ 2349 007 02-08FC-01-FFFFFF
         RQ: r"^0[0-9A-F](00|[0-9A-F]{12})?$",
+        # RQ --- 22:070483 01:063844 --:------ 2349 007 06-0708-03-000027
         EXPIRES: td(hours=4),
     },
     _2D49: {  # unknown
@@ -585,7 +586,6 @@ RAMSES_DEVICES = {
         _12B0: {I_: {}, RP: {}},
         _1F09: {I_: {}, RP: {}, W_: {}},
         _1FC9: {I_: {}, RQ: {}, RP: {}, W_: {}},
-        _1FCA: {W_: {}},
         _1F41: {I_: {}, RP: {}},
         _2249: {I_: {}},  # Hometronics, not Evohome
         _22D9: {RQ: {}},
@@ -750,7 +750,6 @@ RAMSES_DEVICES = {
         _1290: {I_: {}},
         _1F41: {RQ: {}},
         _1FC9: {RP: {}, W_: {}},
-        _1FCA: {W_: {}},
         _22D9: {RQ: {}},
         _2309: {I_: {}},
         _2349: {RQ: {}, RP: {}, W_: {}},
@@ -789,14 +788,11 @@ RAMSES_DEVICES = {
         _10E0: {I_: {}},
         _12C0: {I_: {}},
         _1FC9: {I_: {}},
-        _1FCA: {I_: {}},
         _2309: {I_: {}, RQ: {}, W_: {}},
         _2349: {RQ: {}},
         _30C9: {I_: {}},
         _3120: {I_: {}},
-        _313F: {
-            I_: {}
-        },  # W --- 30:253184 34:010943 --:------ 313F 009 006000070E0E0507E5
+        _313F: {I_: {}},  # W --- 30:253184 34:010943 --:------ 313F 009 006000070E0...
         _3EF0: {RQ: {}},  # when bound direct to a 13:
         _3EF1: {RQ: {}},  # when bound direct to a 13:
     },
@@ -817,7 +813,8 @@ RAMSES_DEVICES["00"] = RAMSES_DEVICES["04"]  # HR80
 RAMSES_DEVICES["21"] = RAMSES_DEVICES["34"]  # T87RF1003
 RAMSES_DEVICES["22"] = RAMSES_DEVICES["12"]  # DTS92
 
-#
+##############
+# RAMSES_ZONES (WIP)
 #
 RAMSES_ZONES = {
     "ALL": {
