@@ -64,6 +64,7 @@ from .protocol import (  # noqa: F401, isort: skip
     _0404,
     _0418,
     _042F,
+    _0B04,
     _1030,
     _1060,
     _1090,
@@ -1096,6 +1097,9 @@ def create_system(gwy, ctl, profile=None, **kwargs) -> System:
 
     system = _SYS_CLASS.get(profile, System)(gwy, ctl, **kwargs)
 
+    if not gwy.serial_port:
+        return system
+
     gwy._add_task(
         system._discover, discover_flag=DISCOVER_SCHEMA, delay=1, period=86400
     )
