@@ -59,6 +59,7 @@ from .protocol import (  # noqa: F401, isort: skip
     _0404,
     _0418,
     _042F,
+    _0B04,
     _1030,
     _1060,
     _1090,
@@ -903,6 +904,9 @@ def create_zone(evo, zone_idx, profile=None, **kwargs) -> Zone:
 
     zone = ZONE_BY_TYPE.get(profile, Zone)(evo, zone_idx, **kwargs)
 
+    if not evo._gwy.serial_port:
+        return zone
+
     evo._gwy._add_task(
         zone._discover, discover_flag=DISCOVER_SCHEMA, delay=2, period=86400
     )
